"""
Copyright Government of Canada 2020

Written by: Xia Liu, National Microbiology Laboratory,
            Public Health Agency of Canada

Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this work except in compliance with the License. You may obtain a copy of the
License at:

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.
"""


class Variant:

    chrom = ''
    pos = ''
    id = ''
    ref = ''
    alt = ''
    qual = ''
    filter = ''
    info = {}
    info_str = ''

    def __init__(self, record):
        self.chrom, self.pos, self.id, self.ref, \
                    self.alt, self.qual, self.filter, \
                    self.info_str = record.split("\t")
        self.info = dict([info_item.split("=") for
                          info_item in self.info_str.split(";")
                          if len(info_item.split("=")) > 1])

    def __str__(self):
        return "{}\t{}\t{}\t{}\t{}\t{}\t{}\t{}\n" \
               .format(self.chrom, self.pos, self.id, self.ref,
                       self.alt, self.qual, self.filter, self.info_str)

    @classmethod
    def get_fields(self):
        return ["Chromosome", "Position_Start", "RSID",
                "Reference_Allele", "Alternate_Allele",
                "Score", "Quality", "Codes"]

    def as_tuple(self):
        return (self.chrom, self.pos, self.id, self.ref,
                self.alt, self.qual, self.filter, self.info_str)

    def as_tuple_vep(self):
        return (self.chrom, self.pos, self.id, self.ref,
                self.alt, self.qual, self.filter, self.info['vep'])
